export interface IVeetingBlocksOptions {
    whitelabelDomain: string;
    version?: string;
    development?: boolean;
    initialized?: () => void;
}
export declare enum MeetingType {
    standard = "standard",
    offTheRecord = "offTheRecord",
    boardroom = "boardroom",
    classroom = "classroom",
    audiobridge = "audiobridge"
}
export declare enum MeetingRecordingType {
    full = "full",
    partial = "partial"
}
export declare enum MeetingRoomAuthType {
    none = "none",
    invited = "invited",
    accountMember = "accountMember",
    platformMember = "platformMember",
    external = "external",
    lobby = "lobby"
}
export declare enum MeetingRoomLayout {
    classic = "classic",
    presentation = "presentation",
    template = "template"
}
export declare enum Availability {
    required = "required",
    optional = "optional",
    hidden = "hidden"
}
export interface IMeetingRoomConfig {
    isNamedRoom: boolean;
    isBreakoutRoom: boolean;
    meetingId: string;
    roomId: string;
    id: string;
    topic: string;
    meetingType: MeetingType;
    dialInEnabled: boolean;
    soleilEnabled: boolean;
    languageChannelsEnabled: boolean;
    languageChannels?: string[];
    passwordProtected: boolean;
    hasVideo: boolean;
    startTime: number;
    endTime: number;
    isOpen: boolean;
    isPreOpen: boolean;
    isClosed: boolean;
    isActive: boolean;
    isDemoMeeting: boolean;
    isPromoMeeting: boolean;
    isFreeMeeting: boolean;
    isRecorded: boolean;
    recordingType?: MeetingRecordingType;
    isAccountValid: boolean;
    maxNumberOfParticipants?: number;
    maxNumberOfPublishers?: number;
    organizerId: string;
    accountId: string;
    logoFileName?: string;
    disableLogs?: boolean;
    broadcastingEnabled?: boolean;
    participantsEmail?: Availability;
    authType?: MeetingRoomAuthType;
    meetingRoomLayout?: MeetingRoomLayout;
    joinMeetingSound?: string;
    leaveMeetingSound?: string;
    closingMeetingSound?: string;
    closedMeetingSound?: string;
    mediaPlayerBroadcastVolumeChange?: boolean;
    mediaPlayerMuteVolumeBeforeOpeningTab?: boolean;
}
export declare enum MeetingRoomVideoResolution {
    "1280x960" = "1280x960",
    "1280x720" = "1280x720",
    "960x720" = "960x720",
    "960x540" = "960x540",
    "640x480" = "640x480",
    "640x360" = "640x360",
    "320x240" = "320x240",
    "320x180" = "320x180",
    "160x120" = "160x120"
}
export interface ICustomMessage {
    from?: string;
    to?: string;
    data?: any;
    onlyToModerators: boolean;
}
export declare type SecondaryVideoPosition = "none" | "left" | "top" | "right" | "bottom";
export declare enum SecondaryVideoSize {
    small = 0.15,
    large = 0.5
}
export interface IVideoPosition {
    participantId: string;
    width: number;
    height: number;
    top: number;
    left: number;
    zIndex: number;
    cssClasses?: string[];
}
export interface IVideoDisplayConfig {
    videoPositions: IVideoPosition[];
    hiddenContainers: boolean[];
}
export interface IMediaInformation {
    audioMuted?: boolean;
    videoMuted?: boolean;
    hasAudio?: boolean;
    hadAudio?: boolean;
    hasVideo?: boolean;
    hadVideo?: boolean;
    videoWidth?: number;
    videoHeight?: number;
}
export interface IParticipantsMediaInformation {
    [participantId: string]: IMediaInformation;
}
export interface IVideoDisplayCalculator {
    calculatePositions(containerWidth: number, containerHeight: number, hasSecondaryArea: boolean, secondaryPosition: SecondaryVideoPosition, secondarySize: SecondaryVideoSize, primaryParticipants: string[], secondaryParticipants: string[], participantsOrder: string[], particpantsMediaInformation: IParticipantsMediaInformation, hasSelfView: boolean, isSelfviewInSecondary: boolean, isTVMode: boolean): IVideoDisplayConfig;
}
export interface IApiParticipant {
    id: string;
    name: string;
    muted?: boolean;
    handRaised?: boolean;
    fromPSTN?: boolean;
    hasVideo?: boolean;
    hadVideo?: boolean;
    joinedAt: number;
}
export interface IApiChatMessage {
    fromParticipantId: string;
    fromParticipantName: string;
    message: string;
}
export interface IApiRemainingTimeUpdate {
    remainingSeconds: number;
}
export interface IScreenshareState {
    active: boolean;
}
export interface IMediaDeviceSettings {
    videoResolution: string;
    audioInputDeviceId: string;
    audioOutputDeviceId: string;
    videoInputDeviceId: string;
}
export declare enum MeetingRoomApiEvent {
    beforeConnecting = "beforeConnecting",
    serverConnected = "serverConnected",
    connected = "connected",
    disconnected = "disconnected",
    leave = "leave",
    participantsUpdated = "participantsUpdated",
    chatMessage = "chatMessage",
    privateChatMessage = "privateChatMessage",
    meetingDurationUpdated = "meetingDurationUpdated",
    meetingRoomConfigUpdated = "meetingRoomConfigUpdated",
    customMessage = "customMessage",
    screenshareStateChange = "screenshareStateChange"
}
export declare type ApiEventCallback = (payload: void | IApiParticipant[] | IApiChatMessage | IApiRemainingTimeUpdate | IMeetingRoomConfig | ICustomMessage | IScreenshareState) => void;
export interface IMeetingRoomApi {
    getVersion(): string;
    getParticipantsList(): IApiParticipant[];
    enableFollowMe(enabled: boolean): void;
    muteVideo(muted: boolean): void;
    toggleMuteVideo(): void;
    muteAudio(muted: boolean): void;
    toggleMuteAudio(): void;
    setMediaStreamConstraints(mediaStreamConstraints: MediaStreamConstraints, merge?: boolean): void;
    connect(audioOnly: boolean): void;
    disconnect(): void;
    setVideoInputDeviceId(deviceId: string, reconnect: boolean): void;
    setAudioInputDeviceId(deviceId: string, reconnect: boolean): void;
    setAudioOutputDeviceId(deviceId: string, reconnect: boolean): void;
    setVideoResolution(resolution: MeetingRoomVideoResolution, reconnect: boolean): void;
    getMediaDeviceSettings(): IMediaDeviceSettings;
    setScreensharingInterceptor(callback: () => void): void;
    startScreensharing(sourceId?: string): void;
    stopScreensharing(): void;
    startRecording(): void;
    stopRecording(): void;
    forceStopScreensharing(): void;
    enterVideoFullscreen(): void;
    sendChatMessage(message: string): void;
    sendPrivateChatMessage(message: string, participantId: string): void;
    sendCustomMessage(message: ICustomMessage): void;
    leaveMeeting(): void;
    setVideoDisplayCalculator(videoDisplayCalculator: IVideoDisplayCalculator): void;
    on(event: MeetingRoomApiEvent, callback: ApiEventCallback): void;
}
export interface IMeetingConnectionConfig {
    meetingId: string;
    moderatorToken?: string;
    participantName: string;
    participantEmail?: string;
    audio: boolean;
    video: boolean;
}
export interface IVeetingBlocksApi extends IMeetingRoomApi {
    loadMeeting(meetingId: string): Promise<IMeetingRoomConfig>;
    joinMeeting(connectionConfig: IMeetingConnectionConfig): Promise<void>;
}
//# sourceMappingURL=blocks.types.d.ts.map