
const gulp = require('gulp'),
	del = require('del'),
	sourcemaps = require('gulp-sourcemaps'),
	plumber = require('gulp-plumber'),

	babel = require('gulp-babel'),
	webpack = require('webpack-stream'),
	uglify = require('gulp-uglify'),
	concat = require('gulp-concat'),
	browserSync = require('browser-sync').create(),

	src_folder = './src/',
	src_assets_folder = src_folder + 'assets/',
	dist_folder = './dist/',
	dist_assets_folder = dist_folder + 'assets/',
	node_modules_folder = './node_modules/',
	dist_node_modules_folder = dist_folder + 'node_modules/',

	node_dependencies = Object.keys(require('./package.json').dependencies || {});

gulp.task('clear', () => del([dist_folder]));

gulp.task('html', () => {
	return gulp.src([src_folder + '**/*.html'], {
		base: src_folder,
		since: gulp.lastRun('html')
	})
		.pipe(gulp.dest(dist_folder))
		.pipe(browserSync.stream());
});

gulp.task('js', () => {
	return gulp.src([src_assets_folder + 'js/**/*.js'], { since: gulp.lastRun('js') })
		.pipe(plumber())
		.pipe(webpack({
			mode: 'production'
		}))
		.pipe(sourcemaps.init())
		.pipe(babel({
			presets: ['@babel/env']
		}))
		.pipe(concat('app.js'))
		.pipe(uglify())
		.pipe(sourcemaps.write('.'))
		.pipe(gulp.dest(dist_assets_folder + 'js'))
		.pipe(browserSync.stream());
});

gulp.task('css', function () {
	return gulp.src([src_assets_folder + 'css/**/*.css'])
		.pipe(concat('app.css'))
		.pipe(gulp.dest(dist_assets_folder + 'css'));
});

gulp.task('vendor', () => {
	if (node_dependencies.length === 0) {
		return new Promise((resolve) => {
			console.log("No dependencies specified");
			resolve();
		});
	}

	return gulp.src(node_dependencies.map(dependency => node_modules_folder + dependency + '/**/*.*'), {
		base: node_modules_folder,
		since: gulp.lastRun('vendor')
	})
		.pipe(gulp.dest(dist_node_modules_folder))
		.pipe(browserSync.stream());
});

gulp.task('build', gulp.series('clear', 'html', 'css', 'js', 'vendor'));

gulp.task('dev', gulp.series('html', 'css', 'js'));

gulp.task('serve', () => {
	return browserSync.init({
		server: {
			baseDir: ['dist']
		},
		port: 3000,
		open: false
	});
});

gulp.task('watch', () => {

	const watchVendor = [];

	node_dependencies.forEach(dependency => {
		watchVendor.push(node_modules_folder + dependency + '/**/*.*');
	});

	const watch = [
		src_folder + '**/*.html',
		src_assets_folder + 'css/**/*.css',
		src_assets_folder + 'js/**/*.js'
	];

	gulp.watch(watch, gulp.series('dev')).on('change', browserSync.reload);
	gulp.watch(watchVendor, gulp.series('vendor')).on('change', browserSync.reload);
});

gulp.task('default', gulp.series('build', gulp.parallel('serve', 'watch')));